//! Tests auto-converted from "sass-spec/spec/libsass/color-functions/rgb/rgba/r.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("r")
}

#[test]
fn test() {
    assert_eq!(
        runner().ok("foo {\
             \n  c-1: rgba(0,-1,0,1);\
             \n  c0: rgba(0,0,0,1);\
             \n  c1: rgba(0,1,0,1);\
             \n  c2: rgba(0,2,0,1);\
             \n  c3: rgba(0,3,0,1);\
             \n  c4: rgba(0,4,0,1);\
             \n  c5: rgba(0,5,0,1);\
             \n  c6: rgba(0,6,0,1);\
             \n  c7: rgba(0,7,0,1);\
             \n  c8: rgba(0,8,0,1);\
             \n  c9: rgba(0,9,0,1);\
             \n  c10: rgba(0,10,0,1);\
             \n  c11: rgba(0,11,0,1);\
             \n  c12: rgba(0,12,0,1);\
             \n  c13: rgba(0,13,0,1);\
             \n  c14: rgba(0,14,0,1);\
             \n  c15: rgba(0,15,0,1);\
             \n  c16: rgba(0,16,0,1);\
             \n  c17: rgba(0,17,0,1);\
             \n  c18: rgba(0,18,0,1);\
             \n  c19: rgba(0,19,0,1);\
             \n  c20: rgba(0,20,0,1);\
             \n  c21: rgba(0,21,0,1);\
             \n  c22: rgba(0,22,0,1);\
             \n  c23: rgba(0,23,0,1);\
             \n  c24: rgba(0,24,0,1);\
             \n  c25: rgba(0,25,0,1);\
             \n  c26: rgba(0,26,0,1);\
             \n  c27: rgba(0,27,0,1);\
             \n  c28: rgba(0,28,0,1);\
             \n  c29: rgba(0,29,0,1);\
             \n  c30: rgba(0,30,0,1);\
             \n  c31: rgba(0,31,0,1);\
             \n  c32: rgba(0,32,0,1);\
             \n  c33: rgba(0,33,0,1);\
             \n  c34: rgba(0,34,0,1);\
             \n  c35: rgba(0,35,0,1);\
             \n  c36: rgba(0,36,0,1);\
             \n  c37: rgba(0,37,0,1);\
             \n  c38: rgba(0,38,0,1);\
             \n  c39: rgba(0,39,0,1);\
             \n  c40: rgba(0,40,0,1);\
             \n  c41: rgba(0,41,0,1);\
             \n  c42: rgba(0,42,0,1);\
             \n  c43: rgba(0,43,0,1);\
             \n  c44: rgba(0,44,0,1);\
             \n  c45: rgba(0,45,0,1);\
             \n  c46: rgba(0,46,0,1);\
             \n  c47: rgba(0,47,0,1);\
             \n  c48: rgba(0,48,0,1);\
             \n  c49: rgba(0,49,0,1);\
             \n  c50: rgba(0,50,0,1);\
             \n  c51: rgba(0,51,0,1);\
             \n  c52: rgba(0,52,0,1);\
             \n  c53: rgba(0,53,0,1);\
             \n  c54: rgba(0,54,0,1);\
             \n  c55: rgba(0,55,0,1);\
             \n  c56: rgba(0,56,0,1);\
             \n  c57: rgba(0,57,0,1);\
             \n  c58: rgba(0,58,0,1);\
             \n  c59: rgba(0,59,0,1);\
             \n  c60: rgba(0,60,0,1);\
             \n  c61: rgba(0,61,0,1);\
             \n  c62: rgba(0,62,0,1);\
             \n  c63: rgba(0,63,0,1);\
             \n  c64: rgba(0,64,0,1);\
             \n  c65: rgba(0,65,0,1);\
             \n  c66: rgba(0,66,0,1);\
             \n  c67: rgba(0,67,0,1);\
             \n  c68: rgba(0,68,0,1);\
             \n  c69: rgba(0,69,0,1);\
             \n  c70: rgba(0,70,0,1);\
             \n  c71: rgba(0,71,0,1);\
             \n  c72: rgba(0,72,0,1);\
             \n  c73: rgba(0,73,0,1);\
             \n  c74: rgba(0,74,0,1);\
             \n  c75: rgba(0,75,0,1);\
             \n  c76: rgba(0,76,0,1);\
             \n  c77: rgba(0,77,0,1);\
             \n  c78: rgba(0,78,0,1);\
             \n  c79: rgba(0,79,0,1);\
             \n  c80: rgba(0,80,0,1);\
             \n  c81: rgba(0,81,0,1);\
             \n  c82: rgba(0,82,0,1);\
             \n  c83: rgba(0,83,0,1);\
             \n  c84: rgba(0,84,0,1);\
             \n  c85: rgba(0,85,0,1);\
             \n  c86: rgba(0,86,0,1);\
             \n  c87: rgba(0,87,0,1);\
             \n  c88: rgba(0,88,0,1);\
             \n  c89: rgba(0,89,0,1);\
             \n  c90: rgba(0,90,0,1);\
             \n  c91: rgba(0,91,0,1);\
             \n  c92: rgba(0,92,0,1);\
             \n  c93: rgba(0,93,0,1);\
             \n  c94: rgba(0,94,0,1);\
             \n  c95: rgba(0,95,0,1);\
             \n  c96: rgba(0,96,0,1);\
             \n  c97: rgba(0,97,0,1);\
             \n  c98: rgba(0,98,0,1);\
             \n  c99: rgba(0,99,0,1);\
             \n  c100: rgba(0,100,0,1);\
             \n  c101: rgba(0,101,0,1);\
             \n  c102: rgba(0,102,0,1);\
             \n  c103: rgba(0,103,0,1);\
             \n  c104: rgba(0,104,0,1);\
             \n  c105: rgba(0,105,0,1);\
             \n  c106: rgba(0,106,0,1);\
             \n  c107: rgba(0,107,0,1);\
             \n  c108: rgba(0,108,0,1);\
             \n  c109: rgba(0,109,0,1);\
             \n  c110: rgba(0,110,0,1);\
             \n  c111: rgba(0,111,0,1);\
             \n  c112: rgba(0,112,0,1);\
             \n  c113: rgba(0,113,0,1);\
             \n  c114: rgba(0,114,0,1);\
             \n  c115: rgba(0,115,0,1);\
             \n  c116: rgba(0,116,0,1);\
             \n  c117: rgba(0,117,0,1);\
             \n  c118: rgba(0,118,0,1);\
             \n  c119: rgba(0,119,0,1);\
             \n  c120: rgba(0,120,0,1);\
             \n  c121: rgba(0,121,0,1);\
             \n  c122: rgba(0,122,0,1);\
             \n  c123: rgba(0,123,0,1);\
             \n  c124: rgba(0,124,0,1);\
             \n  c125: rgba(0,125,0,1);\
             \n  c126: rgba(0,126,0,1);\
             \n  c127: rgba(0,127,0,1);\
             \n  c128: rgba(0,128,0,1);\
             \n  c129: rgba(0,129,0,1);\
             \n  c130: rgba(0,130,0,1);\
             \n  c131: rgba(0,131,0,1);\
             \n  c132: rgba(0,132,0,1);\
             \n  c133: rgba(0,133,0,1);\
             \n  c134: rgba(0,134,0,1);\
             \n  c135: rgba(0,135,0,1);\
             \n  c136: rgba(0,136,0,1);\
             \n  c137: rgba(0,137,0,1);\
             \n  c138: rgba(0,138,0,1);\
             \n  c139: rgba(0,139,0,1);\
             \n  c140: rgba(0,140,0,1);\
             \n  c141: rgba(0,141,0,1);\
             \n  c142: rgba(0,142,0,1);\
             \n  c143: rgba(0,143,0,1);\
             \n  c144: rgba(0,144,0,1);\
             \n  c145: rgba(0,145,0,1);\
             \n  c146: rgba(0,146,0,1);\
             \n  c147: rgba(0,147,0,1);\
             \n  c148: rgba(0,148,0,1);\
             \n  c149: rgba(0,149,0,1);\
             \n  c150: rgba(0,150,0,1);\
             \n  c151: rgba(0,151,0,1);\
             \n  c152: rgba(0,152,0,1);\
             \n  c153: rgba(0,153,0,1);\
             \n  c154: rgba(0,154,0,1);\
             \n  c155: rgba(0,155,0,1);\
             \n  c156: rgba(0,156,0,1);\
             \n  c157: rgba(0,157,0,1);\
             \n  c158: rgba(0,158,0,1);\
             \n  c159: rgba(0,159,0,1);\
             \n  c160: rgba(0,160,0,1);\
             \n  c161: rgba(0,161,0,1);\
             \n  c162: rgba(0,162,0,1);\
             \n  c163: rgba(0,163,0,1);\
             \n  c164: rgba(0,164,0,1);\
             \n  c165: rgba(0,165,0,1);\
             \n  c166: rgba(0,166,0,1);\
             \n  c167: rgba(0,167,0,1);\
             \n  c168: rgba(0,168,0,1);\
             \n  c169: rgba(0,169,0,1);\
             \n  c170: rgba(0,170,0,1);\
             \n  c171: rgba(0,171,0,1);\
             \n  c172: rgba(0,172,0,1);\
             \n  c173: rgba(0,173,0,1);\
             \n  c174: rgba(0,174,0,1);\
             \n  c175: rgba(0,175,0,1);\
             \n  c176: rgba(0,176,0,1);\
             \n  c177: rgba(0,177,0,1);\
             \n  c178: rgba(0,178,0,1);\
             \n  c179: rgba(0,179,0,1);\
             \n  c180: rgba(0,180,0,1);\
             \n  c181: rgba(0,181,0,1);\
             \n  c182: rgba(0,182,0,1);\
             \n  c183: rgba(0,183,0,1);\
             \n  c184: rgba(0,184,0,1);\
             \n  c185: rgba(0,185,0,1);\
             \n  c186: rgba(0,186,0,1);\
             \n  c187: rgba(0,187,0,1);\
             \n  c188: rgba(0,188,0,1);\
             \n  c189: rgba(0,189,0,1);\
             \n  c190: rgba(0,190,0,1);\
             \n  c191: rgba(0,191,0,1);\
             \n  c192: rgba(0,192,0,1);\
             \n  c193: rgba(0,193,0,1);\
             \n  c194: rgba(0,194,0,1);\
             \n  c195: rgba(0,195,0,1);\
             \n  c196: rgba(0,196,0,1);\
             \n  c197: rgba(0,197,0,1);\
             \n  c198: rgba(0,198,0,1);\
             \n  c199: rgba(0,199,0,1);\
             \n  c200: rgba(0,200,0,1);\
             \n  c201: rgba(0,201,0,1);\
             \n  c202: rgba(0,202,0,1);\
             \n  c203: rgba(0,203,0,1);\
             \n  c204: rgba(0,204,0,1);\
             \n  c205: rgba(0,205,0,1);\
             \n  c206: rgba(0,206,0,1);\
             \n  c207: rgba(0,207,0,1);\
             \n  c208: rgba(0,208,0,1);\
             \n  c209: rgba(0,209,0,1);\
             \n  c210: rgba(0,210,0,1);\
             \n  c211: rgba(0,211,0,1);\
             \n  c212: rgba(0,212,0,1);\
             \n  c213: rgba(0,213,0,1);\
             \n  c214: rgba(0,214,0,1);\
             \n  c215: rgba(0,215,0,1);\
             \n  c216: rgba(0,216,0,1);\
             \n  c217: rgba(0,217,0,1);\
             \n  c218: rgba(0,218,0,1);\
             \n  c219: rgba(0,219,0,1);\
             \n  c220: rgba(0,220,0,1);\
             \n  c221: rgba(0,221,0,1);\
             \n  c222: rgba(0,222,0,1);\
             \n  c223: rgba(0,223,0,1);\
             \n  c224: rgba(0,224,0,1);\
             \n  c225: rgba(0,225,0,1);\
             \n  c226: rgba(0,226,0,1);\
             \n  c227: rgba(0,227,0,1);\
             \n  c228: rgba(0,228,0,1);\
             \n  c229: rgba(0,229,0,1);\
             \n  c230: rgba(0,230,0,1);\
             \n  c231: rgba(0,231,0,1);\
             \n  c232: rgba(0,232,0,1);\
             \n  c233: rgba(0,233,0,1);\
             \n  c234: rgba(0,234,0,1);\
             \n  c235: rgba(0,235,0,1);\
             \n  c236: rgba(0,236,0,1);\
             \n  c237: rgba(0,237,0,1);\
             \n  c238: rgba(0,238,0,1);\
             \n  c239: rgba(0,239,0,1);\
             \n  c240: rgba(0,240,0,1);\
             \n  c241: rgba(0,241,0,1);\
             \n  c242: rgba(0,242,0,1);\
             \n  c243: rgba(0,243,0,1);\
             \n  c244: rgba(0,244,0,1);\
             \n  c245: rgba(0,245,0,1);\
             \n  c246: rgba(0,246,0,1);\
             \n  c247: rgba(0,247,0,1);\
             \n  c248: rgba(0,248,0,1);\
             \n  c249: rgba(0,249,0,1);\
             \n  c250: rgba(0,250,0,1);\
             \n  c251: rgba(0,251,0,1);\
             \n  c252: rgba(0,252,0,1);\
             \n  c253: rgba(0,253,0,1);\
             \n  c254: rgba(0,254,0,1);\
             \n  c255: rgba(0,255,0,1);\
             \n  c256: rgba(0,256,0,1);\
             \n}\n\
             \nfoo {\
             \n  c-1: rgba(-1%,0,0,1);\
             \n  c0: rgba(0%,0,0,1);\
             \n  c1: rgba(1%,0,0,1);\
             \n  c2: rgba(2%,0,0,1);\
             \n  c3: rgba(3%,0,0,1);\
             \n  c4: rgba(4%,0,0,1);\
             \n  c5: rgba(5%,0,0,1);\
             \n  c6: rgba(6%,0,0,1);\
             \n  c7: rgba(7%,0,0,1);\
             \n  c8: rgba(8%,0,0,1);\
             \n  c9: rgba(9%,0,0,1);\
             \n  c10: rgba(10%,0,0,1);\
             \n  c11: rgba(11%,0,0,1);\
             \n  c12: rgba(12%,0,0,1);\
             \n  c13: rgba(13%,0,0,1);\
             \n  c14: rgba(14%,0,0,1);\
             \n  c15: rgba(15%,0,0,1);\
             \n  c16: rgba(16%,0,0,1);\
             \n  c17: rgba(17%,0,0,1);\
             \n  c18: rgba(18%,0,0,1);\
             \n  c19: rgba(19%,0,0,1);\
             \n  c20: rgba(20%,0,0,1);\
             \n  c21: rgba(21%,0,0,1);\
             \n  c22: rgba(22%,0,0,1);\
             \n  c23: rgba(23%,0,0,1);\
             \n  c24: rgba(24%,0,0,1);\
             \n  c25: rgba(25%,0,0,1);\
             \n  c26: rgba(26%,0,0,1);\
             \n  c27: rgba(27%,0,0,1);\
             \n  c28: rgba(28%,0,0,1);\
             \n  c29: rgba(29%,0,0,1);\
             \n  c30: rgba(30%,0,0,1);\
             \n  c31: rgba(31%,0,0,1);\
             \n  c32: rgba(32%,0,0,1);\
             \n  c33: rgba(33%,0,0,1);\
             \n  c34: rgba(34%,0,0,1);\
             \n  c35: rgba(35%,0,0,1);\
             \n  c36: rgba(36%,0,0,1);\
             \n  c37: rgba(37%,0,0,1);\
             \n  c38: rgba(38%,0,0,1);\
             \n  c39: rgba(39%,0,0,1);\
             \n  c40: rgba(40%,0,0,1);\
             \n  c41: rgba(41%,0,0,1);\
             \n  c42: rgba(42%,0,0,1);\
             \n  c43: rgba(43%,0,0,1);\
             \n  c44: rgba(44%,0,0,1);\
             \n  c45: rgba(45%,0,0,1);\
             \n  c46: rgba(46%,0,0,1);\
             \n  c47: rgba(47%,0,0,1);\
             \n  c48: rgba(48%,0,0,1);\
             \n  c49: rgba(49%,0,0,1);\
             \n  c50: rgba(50%,0,0,1);\
             \n  c51: rgba(51%,0,0,1);\
             \n  c52: rgba(52%,0,0,1);\
             \n  c53: rgba(53%,0,0,1);\
             \n  c54: rgba(54%,0,0,1);\
             \n  c55: rgba(55%,0,0,1);\
             \n  c56: rgba(56%,0,0,1);\
             \n  c57: rgba(57%,0,0,1);\
             \n  c58: rgba(58%,0,0,1);\
             \n  c59: rgba(59%,0,0,1);\
             \n  c60: rgba(60%,0,0,1);\
             \n  c61: rgba(61%,0,0,1);\
             \n  c62: rgba(62%,0,0,1);\
             \n  c63: rgba(63%,0,0,1);\
             \n  c64: rgba(64%,0,0,1);\
             \n  c65: rgba(65%,0,0,1);\
             \n  c66: rgba(66%,0,0,1);\
             \n  c67: rgba(67%,0,0,1);\
             \n  c68: rgba(68%,0,0,1);\
             \n  c69: rgba(69%,0,0,1);\
             \n  c70: rgba(70%,0,0,1);\
             \n  c71: rgba(71%,0,0,1);\
             \n  c72: rgba(72%,0,0,1);\
             \n  c73: rgba(73%,0,0,1);\
             \n  c74: rgba(74%,0,0,1);\
             \n  c75: rgba(75%,0,0,1);\
             \n  c76: rgba(76%,0,0,1);\
             \n  c77: rgba(77%,0,0,1);\
             \n  c78: rgba(78%,0,0,1);\
             \n  c79: rgba(79%,0,0,1);\
             \n  c80: rgba(80%,0,0,1);\
             \n  c81: rgba(81%,0,0,1);\
             \n  c82: rgba(82%,0,0,1);\
             \n  c83: rgba(83%,0,0,1);\
             \n  c84: rgba(84%,0,0,1);\
             \n  c85: rgba(85%,0,0,1);\
             \n  c86: rgba(86%,0,0,1);\
             \n  c87: rgba(87%,0,0,1);\
             \n  c88: rgba(88%,0,0,1);\
             \n  c89: rgba(89%,0,0,1);\
             \n  c90: rgba(90%,0,0,1);\
             \n  c91: rgba(91%,0,0,1);\
             \n  c92: rgba(92%,0,0,1);\
             \n  c93: rgba(93%,0,0,1);\
             \n  c94: rgba(94%,0,0,1);\
             \n  c95: rgba(95%,0,0,1);\
             \n  c96: rgba(96%,0,0,1);\
             \n  c97: rgba(97%,0,0,1);\
             \n  c98: rgba(98%,0,0,1);\
             \n  c99: rgba(99%,0,0,1);\
             \n  c100: rgba(100%,0,0,1);\
             \n  c101: rgba(101%,0,0,1);\
             \n}\n"),
        "foo {\
         \n  c-1: rgb(0, 0, 0);\
         \n  c0: rgb(0, 0, 0);\
         \n  c1: rgb(0, 1, 0);\
         \n  c2: rgb(0, 2, 0);\
         \n  c3: rgb(0, 3, 0);\
         \n  c4: rgb(0, 4, 0);\
         \n  c5: rgb(0, 5, 0);\
         \n  c6: rgb(0, 6, 0);\
         \n  c7: rgb(0, 7, 0);\
         \n  c8: rgb(0, 8, 0);\
         \n  c9: rgb(0, 9, 0);\
         \n  c10: rgb(0, 10, 0);\
         \n  c11: rgb(0, 11, 0);\
         \n  c12: rgb(0, 12, 0);\
         \n  c13: rgb(0, 13, 0);\
         \n  c14: rgb(0, 14, 0);\
         \n  c15: rgb(0, 15, 0);\
         \n  c16: rgb(0, 16, 0);\
         \n  c17: rgb(0, 17, 0);\
         \n  c18: rgb(0, 18, 0);\
         \n  c19: rgb(0, 19, 0);\
         \n  c20: rgb(0, 20, 0);\
         \n  c21: rgb(0, 21, 0);\
         \n  c22: rgb(0, 22, 0);\
         \n  c23: rgb(0, 23, 0);\
         \n  c24: rgb(0, 24, 0);\
         \n  c25: rgb(0, 25, 0);\
         \n  c26: rgb(0, 26, 0);\
         \n  c27: rgb(0, 27, 0);\
         \n  c28: rgb(0, 28, 0);\
         \n  c29: rgb(0, 29, 0);\
         \n  c30: rgb(0, 30, 0);\
         \n  c31: rgb(0, 31, 0);\
         \n  c32: rgb(0, 32, 0);\
         \n  c33: rgb(0, 33, 0);\
         \n  c34: rgb(0, 34, 0);\
         \n  c35: rgb(0, 35, 0);\
         \n  c36: rgb(0, 36, 0);\
         \n  c37: rgb(0, 37, 0);\
         \n  c38: rgb(0, 38, 0);\
         \n  c39: rgb(0, 39, 0);\
         \n  c40: rgb(0, 40, 0);\
         \n  c41: rgb(0, 41, 0);\
         \n  c42: rgb(0, 42, 0);\
         \n  c43: rgb(0, 43, 0);\
         \n  c44: rgb(0, 44, 0);\
         \n  c45: rgb(0, 45, 0);\
         \n  c46: rgb(0, 46, 0);\
         \n  c47: rgb(0, 47, 0);\
         \n  c48: rgb(0, 48, 0);\
         \n  c49: rgb(0, 49, 0);\
         \n  c50: rgb(0, 50, 0);\
         \n  c51: rgb(0, 51, 0);\
         \n  c52: rgb(0, 52, 0);\
         \n  c53: rgb(0, 53, 0);\
         \n  c54: rgb(0, 54, 0);\
         \n  c55: rgb(0, 55, 0);\
         \n  c56: rgb(0, 56, 0);\
         \n  c57: rgb(0, 57, 0);\
         \n  c58: rgb(0, 58, 0);\
         \n  c59: rgb(0, 59, 0);\
         \n  c60: rgb(0, 60, 0);\
         \n  c61: rgb(0, 61, 0);\
         \n  c62: rgb(0, 62, 0);\
         \n  c63: rgb(0, 63, 0);\
         \n  c64: rgb(0, 64, 0);\
         \n  c65: rgb(0, 65, 0);\
         \n  c66: rgb(0, 66, 0);\
         \n  c67: rgb(0, 67, 0);\
         \n  c68: rgb(0, 68, 0);\
         \n  c69: rgb(0, 69, 0);\
         \n  c70: rgb(0, 70, 0);\
         \n  c71: rgb(0, 71, 0);\
         \n  c72: rgb(0, 72, 0);\
         \n  c73: rgb(0, 73, 0);\
         \n  c74: rgb(0, 74, 0);\
         \n  c75: rgb(0, 75, 0);\
         \n  c76: rgb(0, 76, 0);\
         \n  c77: rgb(0, 77, 0);\
         \n  c78: rgb(0, 78, 0);\
         \n  c79: rgb(0, 79, 0);\
         \n  c80: rgb(0, 80, 0);\
         \n  c81: rgb(0, 81, 0);\
         \n  c82: rgb(0, 82, 0);\
         \n  c83: rgb(0, 83, 0);\
         \n  c84: rgb(0, 84, 0);\
         \n  c85: rgb(0, 85, 0);\
         \n  c86: rgb(0, 86, 0);\
         \n  c87: rgb(0, 87, 0);\
         \n  c88: rgb(0, 88, 0);\
         \n  c89: rgb(0, 89, 0);\
         \n  c90: rgb(0, 90, 0);\
         \n  c91: rgb(0, 91, 0);\
         \n  c92: rgb(0, 92, 0);\
         \n  c93: rgb(0, 93, 0);\
         \n  c94: rgb(0, 94, 0);\
         \n  c95: rgb(0, 95, 0);\
         \n  c96: rgb(0, 96, 0);\
         \n  c97: rgb(0, 97, 0);\
         \n  c98: rgb(0, 98, 0);\
         \n  c99: rgb(0, 99, 0);\
         \n  c100: rgb(0, 100, 0);\
         \n  c101: rgb(0, 101, 0);\
         \n  c102: rgb(0, 102, 0);\
         \n  c103: rgb(0, 103, 0);\
         \n  c104: rgb(0, 104, 0);\
         \n  c105: rgb(0, 105, 0);\
         \n  c106: rgb(0, 106, 0);\
         \n  c107: rgb(0, 107, 0);\
         \n  c108: rgb(0, 108, 0);\
         \n  c109: rgb(0, 109, 0);\
         \n  c110: rgb(0, 110, 0);\
         \n  c111: rgb(0, 111, 0);\
         \n  c112: rgb(0, 112, 0);\
         \n  c113: rgb(0, 113, 0);\
         \n  c114: rgb(0, 114, 0);\
         \n  c115: rgb(0, 115, 0);\
         \n  c116: rgb(0, 116, 0);\
         \n  c117: rgb(0, 117, 0);\
         \n  c118: rgb(0, 118, 0);\
         \n  c119: rgb(0, 119, 0);\
         \n  c120: rgb(0, 120, 0);\
         \n  c121: rgb(0, 121, 0);\
         \n  c122: rgb(0, 122, 0);\
         \n  c123: rgb(0, 123, 0);\
         \n  c124: rgb(0, 124, 0);\
         \n  c125: rgb(0, 125, 0);\
         \n  c126: rgb(0, 126, 0);\
         \n  c127: rgb(0, 127, 0);\
         \n  c128: rgb(0, 128, 0);\
         \n  c129: rgb(0, 129, 0);\
         \n  c130: rgb(0, 130, 0);\
         \n  c131: rgb(0, 131, 0);\
         \n  c132: rgb(0, 132, 0);\
         \n  c133: rgb(0, 133, 0);\
         \n  c134: rgb(0, 134, 0);\
         \n  c135: rgb(0, 135, 0);\
         \n  c136: rgb(0, 136, 0);\
         \n  c137: rgb(0, 137, 0);\
         \n  c138: rgb(0, 138, 0);\
         \n  c139: rgb(0, 139, 0);\
         \n  c140: rgb(0, 140, 0);\
         \n  c141: rgb(0, 141, 0);\
         \n  c142: rgb(0, 142, 0);\
         \n  c143: rgb(0, 143, 0);\
         \n  c144: rgb(0, 144, 0);\
         \n  c145: rgb(0, 145, 0);\
         \n  c146: rgb(0, 146, 0);\
         \n  c147: rgb(0, 147, 0);\
         \n  c148: rgb(0, 148, 0);\
         \n  c149: rgb(0, 149, 0);\
         \n  c150: rgb(0, 150, 0);\
         \n  c151: rgb(0, 151, 0);\
         \n  c152: rgb(0, 152, 0);\
         \n  c153: rgb(0, 153, 0);\
         \n  c154: rgb(0, 154, 0);\
         \n  c155: rgb(0, 155, 0);\
         \n  c156: rgb(0, 156, 0);\
         \n  c157: rgb(0, 157, 0);\
         \n  c158: rgb(0, 158, 0);\
         \n  c159: rgb(0, 159, 0);\
         \n  c160: rgb(0, 160, 0);\
         \n  c161: rgb(0, 161, 0);\
         \n  c162: rgb(0, 162, 0);\
         \n  c163: rgb(0, 163, 0);\
         \n  c164: rgb(0, 164, 0);\
         \n  c165: rgb(0, 165, 0);\
         \n  c166: rgb(0, 166, 0);\
         \n  c167: rgb(0, 167, 0);\
         \n  c168: rgb(0, 168, 0);\
         \n  c169: rgb(0, 169, 0);\
         \n  c170: rgb(0, 170, 0);\
         \n  c171: rgb(0, 171, 0);\
         \n  c172: rgb(0, 172, 0);\
         \n  c173: rgb(0, 173, 0);\
         \n  c174: rgb(0, 174, 0);\
         \n  c175: rgb(0, 175, 0);\
         \n  c176: rgb(0, 176, 0);\
         \n  c177: rgb(0, 177, 0);\
         \n  c178: rgb(0, 178, 0);\
         \n  c179: rgb(0, 179, 0);\
         \n  c180: rgb(0, 180, 0);\
         \n  c181: rgb(0, 181, 0);\
         \n  c182: rgb(0, 182, 0);\
         \n  c183: rgb(0, 183, 0);\
         \n  c184: rgb(0, 184, 0);\
         \n  c185: rgb(0, 185, 0);\
         \n  c186: rgb(0, 186, 0);\
         \n  c187: rgb(0, 187, 0);\
         \n  c188: rgb(0, 188, 0);\
         \n  c189: rgb(0, 189, 0);\
         \n  c190: rgb(0, 190, 0);\
         \n  c191: rgb(0, 191, 0);\
         \n  c192: rgb(0, 192, 0);\
         \n  c193: rgb(0, 193, 0);\
         \n  c194: rgb(0, 194, 0);\
         \n  c195: rgb(0, 195, 0);\
         \n  c196: rgb(0, 196, 0);\
         \n  c197: rgb(0, 197, 0);\
         \n  c198: rgb(0, 198, 0);\
         \n  c199: rgb(0, 199, 0);\
         \n  c200: rgb(0, 200, 0);\
         \n  c201: rgb(0, 201, 0);\
         \n  c202: rgb(0, 202, 0);\
         \n  c203: rgb(0, 203, 0);\
         \n  c204: rgb(0, 204, 0);\
         \n  c205: rgb(0, 205, 0);\
         \n  c206: rgb(0, 206, 0);\
         \n  c207: rgb(0, 207, 0);\
         \n  c208: rgb(0, 208, 0);\
         \n  c209: rgb(0, 209, 0);\
         \n  c210: rgb(0, 210, 0);\
         \n  c211: rgb(0, 211, 0);\
         \n  c212: rgb(0, 212, 0);\
         \n  c213: rgb(0, 213, 0);\
         \n  c214: rgb(0, 214, 0);\
         \n  c215: rgb(0, 215, 0);\
         \n  c216: rgb(0, 216, 0);\
         \n  c217: rgb(0, 217, 0);\
         \n  c218: rgb(0, 218, 0);\
         \n  c219: rgb(0, 219, 0);\
         \n  c220: rgb(0, 220, 0);\
         \n  c221: rgb(0, 221, 0);\
         \n  c222: rgb(0, 222, 0);\
         \n  c223: rgb(0, 223, 0);\
         \n  c224: rgb(0, 224, 0);\
         \n  c225: rgb(0, 225, 0);\
         \n  c226: rgb(0, 226, 0);\
         \n  c227: rgb(0, 227, 0);\
         \n  c228: rgb(0, 228, 0);\
         \n  c229: rgb(0, 229, 0);\
         \n  c230: rgb(0, 230, 0);\
         \n  c231: rgb(0, 231, 0);\
         \n  c232: rgb(0, 232, 0);\
         \n  c233: rgb(0, 233, 0);\
         \n  c234: rgb(0, 234, 0);\
         \n  c235: rgb(0, 235, 0);\
         \n  c236: rgb(0, 236, 0);\
         \n  c237: rgb(0, 237, 0);\
         \n  c238: rgb(0, 238, 0);\
         \n  c239: rgb(0, 239, 0);\
         \n  c240: rgb(0, 240, 0);\
         \n  c241: rgb(0, 241, 0);\
         \n  c242: rgb(0, 242, 0);\
         \n  c243: rgb(0, 243, 0);\
         \n  c244: rgb(0, 244, 0);\
         \n  c245: rgb(0, 245, 0);\
         \n  c246: rgb(0, 246, 0);\
         \n  c247: rgb(0, 247, 0);\
         \n  c248: rgb(0, 248, 0);\
         \n  c249: rgb(0, 249, 0);\
         \n  c250: rgb(0, 250, 0);\
         \n  c251: rgb(0, 251, 0);\
         \n  c252: rgb(0, 252, 0);\
         \n  c253: rgb(0, 253, 0);\
         \n  c254: rgb(0, 254, 0);\
         \n  c255: rgb(0, 255, 0);\
         \n  c256: rgb(0, 255, 0);\
         \n}\
         \nfoo {\
         \n  c-1: rgb(0, 0, 0);\
         \n  c0: rgb(0, 0, 0);\
         \n  c1: rgb(2.55, 0, 0);\
         \n  c2: rgb(5.1, 0, 0);\
         \n  c3: rgb(7.65, 0, 0);\
         \n  c4: rgb(10.2, 0, 0);\
         \n  c5: rgb(12.75, 0, 0);\
         \n  c6: rgb(15.3, 0, 0);\
         \n  c7: rgb(17.85, 0, 0);\
         \n  c8: rgb(20.4, 0, 0);\
         \n  c9: rgb(22.95, 0, 0);\
         \n  c10: rgb(25.5, 0, 0);\
         \n  c11: rgb(28.05, 0, 0);\
         \n  c12: rgb(30.6, 0, 0);\
         \n  c13: rgb(33.15, 0, 0);\
         \n  c14: rgb(35.7, 0, 0);\
         \n  c15: rgb(38.25, 0, 0);\
         \n  c16: rgb(40.8, 0, 0);\
         \n  c17: rgb(43.35, 0, 0);\
         \n  c18: rgb(45.9, 0, 0);\
         \n  c19: rgb(48.45, 0, 0);\
         \n  c20: rgb(51, 0, 0);\
         \n  c21: rgb(53.55, 0, 0);\
         \n  c22: rgb(56.1, 0, 0);\
         \n  c23: rgb(58.65, 0, 0);\
         \n  c24: rgb(61.2, 0, 0);\
         \n  c25: rgb(63.75, 0, 0);\
         \n  c26: rgb(66.3, 0, 0);\
         \n  c27: rgb(68.85, 0, 0);\
         \n  c28: rgb(71.4, 0, 0);\
         \n  c29: rgb(73.95, 0, 0);\
         \n  c30: rgb(76.5, 0, 0);\
         \n  c31: rgb(79.05, 0, 0);\
         \n  c32: rgb(81.6, 0, 0);\
         \n  c33: rgb(84.15, 0, 0);\
         \n  c34: rgb(86.7, 0, 0);\
         \n  c35: rgb(89.25, 0, 0);\
         \n  c36: rgb(91.8, 0, 0);\
         \n  c37: rgb(94.35, 0, 0);\
         \n  c38: rgb(96.9, 0, 0);\
         \n  c39: rgb(99.45, 0, 0);\
         \n  c40: rgb(102, 0, 0);\
         \n  c41: rgb(104.55, 0, 0);\
         \n  c42: rgb(107.1, 0, 0);\
         \n  c43: rgb(109.65, 0, 0);\
         \n  c44: rgb(112.2, 0, 0);\
         \n  c45: rgb(114.75, 0, 0);\
         \n  c46: rgb(117.3, 0, 0);\
         \n  c47: rgb(119.85, 0, 0);\
         \n  c48: rgb(122.4, 0, 0);\
         \n  c49: rgb(124.95, 0, 0);\
         \n  c50: rgb(127.5, 0, 0);\
         \n  c51: rgb(130.05, 0, 0);\
         \n  c52: rgb(132.6, 0, 0);\
         \n  c53: rgb(135.15, 0, 0);\
         \n  c54: rgb(137.7, 0, 0);\
         \n  c55: rgb(140.25, 0, 0);\
         \n  c56: rgb(142.8, 0, 0);\
         \n  c57: rgb(145.35, 0, 0);\
         \n  c58: rgb(147.9, 0, 0);\
         \n  c59: rgb(150.45, 0, 0);\
         \n  c60: rgb(153, 0, 0);\
         \n  c61: rgb(155.55, 0, 0);\
         \n  c62: rgb(158.1, 0, 0);\
         \n  c63: rgb(160.65, 0, 0);\
         \n  c64: rgb(163.2, 0, 0);\
         \n  c65: rgb(165.75, 0, 0);\
         \n  c66: rgb(168.3, 0, 0);\
         \n  c67: rgb(170.85, 0, 0);\
         \n  c68: rgb(173.4, 0, 0);\
         \n  c69: rgb(175.95, 0, 0);\
         \n  c70: rgb(178.5, 0, 0);\
         \n  c71: rgb(181.05, 0, 0);\
         \n  c72: rgb(183.6, 0, 0);\
         \n  c73: rgb(186.15, 0, 0);\
         \n  c74: rgb(188.7, 0, 0);\
         \n  c75: rgb(191.25, 0, 0);\
         \n  c76: rgb(193.8, 0, 0);\
         \n  c77: rgb(196.35, 0, 0);\
         \n  c78: rgb(198.9, 0, 0);\
         \n  c79: rgb(201.45, 0, 0);\
         \n  c80: rgb(204, 0, 0);\
         \n  c81: rgb(206.55, 0, 0);\
         \n  c82: rgb(209.1, 0, 0);\
         \n  c83: rgb(211.65, 0, 0);\
         \n  c84: rgb(214.2, 0, 0);\
         \n  c85: rgb(216.75, 0, 0);\
         \n  c86: rgb(219.3, 0, 0);\
         \n  c87: rgb(221.85, 0, 0);\
         \n  c88: rgb(224.4, 0, 0);\
         \n  c89: rgb(226.95, 0, 0);\
         \n  c90: rgb(229.5, 0, 0);\
         \n  c91: rgb(232.05, 0, 0);\
         \n  c92: rgb(234.6, 0, 0);\
         \n  c93: rgb(237.15, 0, 0);\
         \n  c94: rgb(239.7, 0, 0);\
         \n  c95: rgb(242.25, 0, 0);\
         \n  c96: rgb(244.8, 0, 0);\
         \n  c97: rgb(247.35, 0, 0);\
         \n  c98: rgb(249.9, 0, 0);\
         \n  c99: rgb(252.45, 0, 0);\
         \n  c100: rgb(255, 0, 0);\
         \n  c101: rgb(255, 0, 0);\
         \n}\n"
    );
}
